import { Injectable, InjectionToken, Inject } from '@angular/core';
import * as Msal from 'msal';
export const MSAL_CONFIG = new InjectionToken('MSAL_CONFIG');
export class MsalService {
    constructor(config) {
        this.config = config;
        const authority = (config.tenant && config.signUpSignInPolicy) ?
            `https://login.microsoftonline.com/tfp/${config.tenant}/${config.signUpSignInPolicy}` : '';
        this.app = new Msal.UserAgentApplication(config.clientID, authority, this.authCallback, {
            redirectUri: window.location.origin
        });
        this.app = new Msal.UserAgentApplication(config.clientID, authority, () => { });
    }
    get authenticated() {
        return !!this.app.getUser();
    }
    get token() {
        return this.getToken();
    }
    login() {
        return this.app.loginPopup(this.config.graphScopes)
            .then((idToken) => {
            return this.getToken().then(() => {
                Promise.resolve(this.app.getUser());
            });
        });
    }
    ;
    getToken() {
        return this.app.acquireTokenSilent(this.config.graphScopes)
            .then(token => {
            return token;
        }).catch(error => {
            return this.app.acquireTokenPopup(this.config.graphScopes)
                .then(token => {
                return Promise.resolve(token);
            }).catch(innererror => {
                return Promise.resolve('');
            });
        });
    }
    logout() {
        this.app.logout();
    }
    authCallback(errorDesc, token, error, tokenType) {
        if (error) {
            console.error(`${error} ${errorDesc}`);
        }
    }
}
MsalService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MsalService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [MSAL_CONFIG,] },] },
];
//# sourceMappingURL=msal.service.js.map